# Common function to check integrity of the function parameters for functions Electre_3 and Electre_3_sensitivity
#
# parameters
#   PM - performance matrix criteria in columns and alternatives in rows
#   w  - weights
#   P  - preference threshold
#   Q  - indifference threshold
#   V  - veto threshold
#   alpha - first discrimination threshold
#   beta  - second discrimination threshold
Electre_3_paramCheck <- function(PM, w, P, Q, V,
                                 alpha = 0.3, beta = 0.15){

  if (is.null(dim(PM))) stop('less than 2 criteria or 2 alternatives')
  if (!(is.matrix(PM) || (is.data.frame(PM)))) stop('wrong performance matrix, must be a matrix or a data frame')
  if (!is.numeric(unlist(PM))) stop('Only numeric values in performance matrix expected')
  if (!is.vector(w)) stop('criteria weights should be a vector')
  if (!is.numeric(w)) stop('criteria weights should be a numeric vector')
  ncri <- ncol(PM)  #no. of criteria
  if (ncri != length(w)) stop('number of criteria weights must be same as number of criteria')
  if (!is.vector(P)) stop('preference thresholds should be a vector')
  if (!is.numeric(P)) stop('preference thresholds should be a numeric vector')
  if (length(P) != ncri) stop('number of preference thresholds != number of criteria')
  if (!(is.vector(Q))) stop('indifference thresholds should be a vector')
  if (!is.numeric(Q)) stop('indifference thresholds be a numeric vector')
  if (length(Q) != ncri) stop('number of indifference thresholds != number of criteria')
  if (!is.vector(V)) stop('veto thresholds should be a vector')
  if (!is.numeric(V)) stop('veto thresholds be a numeric vector')
  if (length(V) != ncri) stop('number of veto thresholds != number of criteria')
  if (all(P == Q)) stop('Preference and indifference thresholds are defined same. Revisit to distinguish them or use another method.')
  if (!is.numeric(alpha)) stop('alpha discrimination threshold should be a number')
  if (!is.numeric(beta)) stop('beta discrimination threshold should be a number')
  if (alpha < beta) stop('alpha shoud be > then beta (discrimination threshold)')

}
