# PROMETHEE IU function
#
# parameters
#   PM - performance matrix
#   preferenceFunction - vector of preference functions types to derive preference when comparing PM
#   w - weights
#   minmax - min/max value or vector of mixed values for criteria orientation
#   indifferenceTreshold list of indifference thresholds
#   prefferenceThreshold list of prefference thresholds
#   intermediateThreshold lish of intermediate thresholds for Gaussian function type
#   VERBOSE - TRUE to dump outputs to console
PROMETHEE_II <- function(PM, preferenceFunction, w, minmax = 'max',
                        indifferenceTreshold = NULL, prefferenceThreshold = NULL,
                        intermediateThreshold = NULL, VERBOSE = FALSE){
  #params consistency check centralized in generalized PROMETHEE function
  nalt <- nrow(PM)  #no. of alternatives
  alt  <- rownames(PM) #list of alternatives
  #here is only minmax
  PM <- util_pm_minmax(PM, minmax) #validate minmax and invert scales if neccessary
  #end of parameter consistency check

  flow <- PROMETHEE(PM, preferenceFunction, w, indifferenceTreshold, prefferenceThreshold, intermediateThreshold)
  pf <- flow$positiveFlow
  nf <- flow$negativeFlow
  nof <- flow$netFlow #net outranking flow (nof)
  names(nof) <- alt
  ordering <- sort(nof, decreasing = T)
  names_ord <- names(ordering)
  o <- 1
  rank <- list()
  for(i in 1:nalt){
    if(i == 1) { #first alternative in list
      talt <- names_ord[i]
    }else{
      if(ordering[i] == ordering[i-1]) {
        talt <- cat(talt, ', ', names_ord[i])
      }else{
        rank[o] <- talt
        o <- o + 1
        talt <- names_ord[i]
      }
      if(i == nalt) rank[o] <- talt #last alternative in list, write out result
    }
  }
  #establish preference system
  pref <- matrix(data = 0, nrow = nalt, ncol = nalt)
  for(i in 1:nalt){
    for(j in 1:nalt){
      pref[i,j] <- ifelse(nof[i] > nof[j], 1, 0)
    }
  }
  rownames(pref) <- alt
  colnames(pref) <- alt
  class(pref) <- 'prefM'

  if(VERBOSE){
    plot(pref)
    print('Preference matrix')
    print(pref)
    print('Final order as per net outranking flow')
    print(ordering)
    print('Ranked list')
    print(rank)
  }

  out <- list(
    positiveFlow = pf,
    negativeFlow = nf,
    netFlow = nof,
    preferenceDegree = flow$preferenceDegree,
    preferenceDegreeUnw = flow$preferenceDegreeUnw,
    pairweiseComparison = flow$pairweiseComparison,
    rankedList = rank,
    rankedListNOF = ordering,
    preferenceMatrix = pref
  )
  return(out)
}
